@@ -48,6 +48,7 @@ class Config
         bool bShowWishlist;
         bool bAutomaticXMLCreation;
         bool bSaveChangelogs;
+        bool bRespectUmask;
         std::string sGameRegex;
         std::string sDirectory;
         std::string sCacheDirectory;
@@ -62,8 +63,10 @@ class Config
         std::string sConfigFilePath;
         std::string sBlacklistFilePath;
         std::string sIgnorelistFilePath;
+        std::string sGameHasDLCListFilePath;
         std::string sOrphanRegex;
         std::string sCoverList;
+        std::string sGameHasDLCList;
         std::string sReportFilePath;
         std::string sInstallersSubdir;
         std::string sExtrasSubdir;
@@ -76,12 +79,14 @@ class Config
         std::string sLanguagePriority;
         std::string sPlatformPriority;
         std::string sIgnoreDLCCountRegex;
+        std::string sCACertPath;
         std::vector<unsigned int> vLanguagePriority;
         std::vector<unsigned int> vPlatformPriority;
 
         unsigned int iInstallerPlatform;
         unsigned int iInstallerLanguage;
         unsigned int iInclude;
+        unsigned int iThreads;
         int iRetries;
         int iWait;
         int iCacheValid;
@@ -90,6 +95,7 @@ class Config
         long int iTimeout;
         Blacklist blacklist;
         Blacklist ignorelist;
+        Blacklist gamehasdlc;
 };
 
 #endif // CONFIG_H__
