@@ -25,6 +25,7 @@
 #include "api.h"
 #include "progressbar.h"
 #include "website.h"
+#include "threadsafequeue.h"
 #include <curl/curl.h>
 #include <json/json.h>
 #include <ctime>
@@ -48,6 +49,15 @@ class Timer
         struct timeval last_update;
 };
 
+struct xferInfo
+{
+    unsigned int tid;
+    CURL* curlhandle;
+    Timer timer;
+    std::deque< std::pair<time_t, uintmax_t> > TimeAndSize;
+    curl_off_t offset;
+};
+
 class Downloader
 {
     public:
@@ -55,14 +65,14 @@ class Downloader
         virtual ~Downloader();
         int init();
         int login();
-        void listGames();
+        int listGames();
         void updateCheck();
         void repair();
         void download();
         void checkOrphans();
         void checkStatus();
         void updateCache();
-        void downloadFileWithId(const std::string& fileid_string, const std::string& output_filepath);
+        int downloadFileWithId(const std::string& fileid_string, const std::string& output_filepath);
         void showWishlist();
         CURL* curlhandle;
         Timer timer;
@@ -84,11 +94,15 @@ class Downloader
         int loadGameDetailsCache();
         int saveGameDetailsCache();
         std::vector<gameDetails> getGameDetailsFromJsonNode(Json::Value root, const int& recursion_level = 0);
-        std::vector<gameFile> getExtrasFromJSON(const Json::Value& json, const std::string& gamename);
-        std::string getSerialsFromJSON(const Json::Value& json);
+        static std::vector<gameFile> getExtrasFromJSON(const Json::Value& json, const std::string& gamename, const Config& config);
+        static std::string getSerialsFromJSON(const Json::Value& json);
         void saveSerials(const std::string& serials, const std::string& filepath);
-        std::string getChangelogFromJSON(const Json::Value& json);
+        static std::string getChangelogFromJSON(const Json::Value& json);
         void saveChangelog(const std::string& changelog, const std::string& filepath);
+        static void processDownloadQueue(Config conf, const unsigned int& tid);
+        static int progressCallbackForThread(void *clientp, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow);
+        void printProgress();
+        static void getGameDetailsThread(Config config, const unsigned int& tid);
 
         static int progressCallback(void *clientp, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow);
         static size_t writeMemoryCallback(char *ptr, size_t size, size_t nmemb, void *userp);
