@@ -55,6 +55,7 @@ int main(int argc, char *argv[])
     config.sConfigFilePath = config.sConfigDirectory + "/config.cfg";
     config.sBlacklistFilePath = config.sConfigDirectory + "/blacklist.txt";
     config.sIgnorelistFilePath = config.sConfigDirectory + "/ignorelist.txt";
+    config.sGameHasDLCListFilePath = config.sConfigDirectory + "/game_has_dlc.txt";
 
     std::string priority_help_text = "Set priority by separating values with \",\"\nCombine values by separating with \"+\"";
     // Create help text for --platform option
@@ -143,6 +144,8 @@ int main(int argc, char *argv[])
             ("wishlist", bpo::value<bool>(&config.bShowWishlist)->zero_tokens()->default_value(false), "Show wishlist")
             ("login-api", bpo::value<bool>(&config.bLoginAPI)->zero_tokens()->default_value(false), "Login (API only)")
             ("login-website", bpo::value<bool>(&config.bLoginHTTP)->zero_tokens()->default_value(false), "Login (website only)")
+            ("cacert", bpo::value<std::string>(&config.sCACertPath)->default_value(""), "Path to CA certificate bundle in PEM format")
+            ("respect-umask", bpo::value<bool>(&config.bRespectUmask)->zero_tokens()->default_value(false), "Do not adjust permissions of sensitive files")
         ;
         // Commandline options (config file)
         options_cli_cfg.add_options()
@@ -154,7 +157,7 @@ int main(int argc, char *argv[])
             ("language", bpo::value<std::string>(&sInstallerLanguage)->default_value("en"), language_text.c_str())
             ("no-remote-xml", bpo::value<bool>(&bNoRemoteXML)->zero_tokens()->default_value(false), "Don't use remote XML for repair")
             ("no-unicode", bpo::value<bool>(&bNoUnicode)->zero_tokens()->default_value(false), "Don't use Unicode in the progress bar")
-            ("no-color", bpo::value<bool>(&bNoColor)->zero_tokens()->default_value(false), "Don't use coloring in the progress bar")
+            ("no-color", bpo::value<bool>(&bNoColor)->zero_tokens()->default_value(false), "Don't use coloring in the progress bar or status messages")
             ("no-duplicate-handling", bpo::value<bool>(&bNoDuplicateHandler)->zero_tokens()->default_value(false), "Don't use duplicate handler for installers\nDuplicate installers from different languages are handled separately")
             ("no-subdirectories", bpo::value<bool>(&bNoSubDirectories)->zero_tokens()->default_value(false), "Don't create subdirectories for extras, patches and language packs")
             ("verbose", bpo::value<bool>(&config.bVerbose)->zero_tokens()->default_value(false), "Print lots of information")
@@ -162,7 +165,7 @@ int main(int argc, char *argv[])
             ("timeout", bpo::value<long int>(&config.iTimeout)->default_value(10), "Set timeout for connection\nMaximum time in seconds that connection phase is allowed to take")
             ("retries", bpo::value<int>(&config.iRetries)->default_value(3), "Set maximum number of retries on failed download")
             ("wait", bpo::value<int>(&config.iWait)->default_value(0), "Time to wait between requests (milliseconds)")
-            ("cover-list", bpo::value<std::string>(&config.sCoverList)->default_value("https://sites.google.com/site/gogdownloader/covers.xml"), "Set URL for cover list")
+            ("cover-list", bpo::value<std::string>(&config.sCoverList)->default_value("https://raw.githubusercontent.com/Sude-/lgogdownloader-lists/master/covers.xml"), "Set URL for cover list")
             ("subdir-installers", bpo::value<std::string>(&config.sInstallersSubdir)->default_value(""), ("Set subdirectory for extras" + subdir_help_text).c_str())
             ("subdir-extras", bpo::value<std::string>(&config.sExtrasSubdir)->default_value("extras"), ("Set subdirectory for extras" + subdir_help_text).c_str())
             ("subdir-patches", bpo::value<std::string>(&config.sPatchesSubdir)->default_value("patches"), ("Set subdirectory for patches" + subdir_help_text).c_str())
@@ -177,6 +180,8 @@ int main(int argc, char *argv[])
             ("exclude", bpo::value<std::string>(&sExcludeOptions)->default_value("covers"), ("Select what not to download/list/repair\n" + include_options_text).c_str())
             ("automatic-xml-creation", bpo::value<bool>(&config.bAutomaticXMLCreation)->zero_tokens()->default_value(false), "Automatically create XML data after download has completed")
             ("save-changelogs", bpo::value<bool>(&config.bSaveChangelogs)->zero_tokens()->default_value(false), "Save changelogs when downloading")
+            ("threads", bpo::value<unsigned int>(&config.iThreads)->default_value(4), "Number of download threads")
+            ("dlc-list", bpo::value<std::string>(&config.sGameHasDLCList)->default_value("https://raw.githubusercontent.com/Sude-/lgogdownloader-lists/master/game_has_dlc.txt"), "Set URL for list of games that have DLC")
         ;
         // Options read from config file
         options_cfg_only.add_options()
@@ -295,6 +300,30 @@ int main(int argc, char *argv[])
             }
         }
 
+        if (config.sIgnoreDLCCountRegex.empty())
+        {
+            if (boost::filesystem::exists(config.sGameHasDLCListFilePath))
+            {
+                std::ifstream ifs(config.sGameHasDLCListFilePath.c_str());
+                if (!ifs)
+                {
+                    std::cerr << "Could not open list of games that have dlc: " << config.sGameHasDLCListFilePath << std::endl;
+                    return 1;
+                }
+                else
+                {
+                    std::string line;
+                    std::vector<std::string> lines;
+                    while (!ifs.eof())
+                    {
+                        std::getline(ifs, line);
+                        lines.push_back(std::move(line));
+                    }
+                    config.gamehasdlc.initialize(lines);
+                }
+            }
+        }
+
         if (vm.count("chunk-size"))
             config.iChunkSize <<= 20; // Convert chunk size from bytes to megabytes
 
@@ -311,6 +340,12 @@ int main(int argc, char *argv[])
         if (config.iWait > 0)
             config.iWait *= 1000;
 
+        if (config.iThreads < 1)
+        {
+            config.iThreads = 1;
+            set_vm_value(vm, "threads", config.iThreads);
+        }
+
         config.bVerifyPeer = !bInsecure;
         config.bColor = !bNoColor;
         config.bUnicode = !bNoUnicode;
@@ -421,6 +456,15 @@ int main(int argc, char *argv[])
         config.sDirectory = "./"; // Directory wasn't specified, use current directory
     }
 
+    // CA certificate bundle
+    if (config.sCACertPath.empty())
+    {
+        // Use CURL_CA_BUNDLE environment variable for CA certificate path if it is set
+        char *ca_bundle = getenv("CURL_CA_BUNDLE");
+        if (ca_bundle)
+            config.sCACertPath = (std::string)ca_bundle;
+    }
+
     if (!unrecognized_options_cfg.empty() && (!config.bSaveConfig || !config.bResetConfig))
     {
         std::cerr << "Unrecognized options in " << config.sConfigFilePath << std::endl;
@@ -445,8 +489,11 @@ int main(int argc, char *argv[])
     }
 
     // Make sure that config file and cookie file are only readable/writable by owner
-    Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
-    Util::setFilePermissions(config.sCookiePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
+    if (!config.bRespectUmask)
+    {
+        Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
+        Util::setFilePermissions(config.sCookiePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
+    }
 
     if (config.bSaveConfig || iLoginResult == 1)
     {
@@ -503,7 +550,8 @@ int main(int argc, char *argv[])
                 }
             }
             ofs.close();
-            Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
+            if (!config.bRespectUmask)
+                Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
             if (config.bSaveConfig)
                 return 0;
         }
@@ -524,7 +572,8 @@ int main(int argc, char *argv[])
                 ofs << "secret = " << config.sSecret << std::endl;
             }
             ofs.close();
-            Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
+            if (!config.bRespectUmask)
+                Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
             return 0;
         }
         else
@@ -533,6 +582,9 @@ int main(int argc, char *argv[])
             return 1;
         }
     }
+
+    int res = 0;
+
     if (config.bShowWishlist)
         downloader.showWishlist();
     else if (config.bUpdateCache)
@@ -543,7 +595,7 @@ int main(int argc, char *argv[])
     {
         for (std::vector<std::string>::iterator it = vFileIdStrings.begin(); it != vFileIdStrings.end(); it++)
         {
-            downloader.downloadFileWithId(*it, config.sOutputFilename);
+            res |= downloader.downloadFileWithId(*it, config.sOutputFilename) ? 1 : 0;
         }
     }
     else if (config.bRepair) // Repair file
@@ -551,7 +603,7 @@ int main(int argc, char *argv[])
     else if (config.bDownload) // Download games
         downloader.download();
     else if (config.bListDetails || config.bList) // Detailed list of games/extras
-        downloader.listGames();
+        res = downloader.listGames();
     else if (!config.sOrphanRegex.empty()) // Check for orphaned files if regex for orphans is set
         downloader.checkOrphans();
     else if (config.bCheckStatus)
@@ -570,5 +622,5 @@ int main(int argc, char *argv[])
     if (!config.sOrphanRegex.empty() && config.bDownload)
         downloader.checkOrphans();
 
-    return 0;
+    return res;
 }
