@@ -8,7 +8,7 @@
 
 #include <boost/filesystem.hpp>
 #include <boost/algorithm/string/case_conv.hpp>
-#include <tinyxml.h>
+#include <tinyxml2.h>
 #include <json/json.h>
 #include <fstream>
 #include <sys/ioctl.h>
@@ -132,11 +132,11 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
                 << "Chunks: " << chunks << std::endl
                 << "Chunk size: " << (chunk_size >> 20) << " MB" << std::endl;
 
-    TiXmlDocument xml;
-    TiXmlElement *fileElem = new TiXmlElement("file");
-    fileElem->SetAttribute("name", filename);
+    tinyxml2::XMLDocument xml;
+    tinyxml2::XMLElement *fileElem = xml.NewElement("file");
+    fileElem->SetAttribute("name", filename.c_str());
     fileElem->SetAttribute("chunks", chunks);
-    fileElem->SetAttribute("total_size", std::to_string(filesize));
+    fileElem->SetAttribute("total_size", std::to_string(filesize).c_str());
 
     std::cout << "Getting MD5 for chunks" << std::endl;
 
@@ -175,12 +175,12 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
 
         free(chunk);
 
-        TiXmlElement *chunkElem = new TiXmlElement("chunk");
+        tinyxml2::XMLElement *chunkElem = xml.NewElement("chunk");
         chunkElem->SetAttribute("id", i);
-        chunkElem->SetAttribute("from", std::to_string(range_begin));
-        chunkElem->SetAttribute("to", std::to_string(range_end));
+        chunkElem->SetAttribute("from", std::to_string(range_begin).c_str());
+        chunkElem->SetAttribute("to", std::to_string(range_end).c_str());
         chunkElem->SetAttribute("method", "md5");
-        TiXmlText *text = new TiXmlText(hash);
+        tinyxml2::XMLText *text = xml.NewText(hash.c_str());
         chunkElem->LinkEndChild(text);
         fileElem->LinkEndChild(chunkElem);
 
@@ -192,15 +192,15 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
     rhash_print(rhash_result, rhash_context, RHASH_MD5, RHPR_HEX);
     rhash_free(rhash_context);
 
-    std::string file_md5 = rhash_result;
-    std::cout << std::endl << "MD5: " << file_md5 << std::endl;
-    fileElem->SetAttribute("md5", file_md5);
+    std::cout << std::endl << "MD5: " << rhash_result << std::endl;
+    fileElem->SetAttribute("md5", rhash_result);
 
     xml.LinkEndChild(fileElem);
 
     std::cout << "Writing XML: " << filenameXML << std::endl;
     if ((xmlfile=fopen(filenameXML.c_str(), "w"))!=NULL) {
-        xml.Print(xmlfile);
+        tinyxml2::XMLPrinter printer(xmlfile);
+        xml.Print(&printer);
         fclose(xmlfile);
         res = 1;
     } else {
@@ -540,3 +540,46 @@ void Util::parseOptionString(const std::string &option_string, std::vector<unsig
         type |= value;
     }
 }
+
+std::string Util::getLocalFileHash(const std::string& xml_dir, const std::string& filepath, const std::string& gamename)
+{
+    std::string localHash;
+    boost::filesystem::path path = filepath;
+    boost::filesystem::path local_xml_file;
+    if (!gamename.empty())
+        local_xml_file = xml_dir + "/" + gamename + "/" + path.filename().string() + ".xml";
+    else
+        local_xml_file = xml_dir + "/" + path.filename().string() + ".xml";
+
+    if (boost::filesystem::exists(local_xml_file))
+    {
+        tinyxml2::XMLDocument local_xml;
+        local_xml.LoadFile(local_xml_file.string().c_str());
+        tinyxml2::XMLElement *fileElem = local_xml.FirstChildElement("file");
+
+        if (fileElem)
+        {
+            localHash = fileElem->Attribute("md5");
+        }
+    }
+    else if (boost::filesystem::exists(path) && boost::filesystem::is_regular_file(path))
+    {
+        localHash = Util::getFileHash(path.string(), RHASH_MD5);
+    }
+
+    return localHash;
+}
+
+void Util::shortenStringToTerminalWidth(std::string& str)
+{
+    int iStrLen = static_cast<int>(str.length());
+    int iTermWidth = Util::getTerminalWidth();
+    if (iStrLen >= iTermWidth)
+    {
+        size_t chars_to_remove = (iStrLen - iTermWidth) + 4;
+        size_t middle = iStrLen / 2;
+        size_t pos1 = middle - (chars_to_remove / 2);
+        size_t pos2 = middle + (chars_to_remove / 2);
+        str.replace(str.begin()+pos1, str.begin()+pos2, "...");
+    }
+}
