@@ -31,6 +31,8 @@ Website::Website(Config &conf)
     curl_easy_setopt(curlhandle, CURLOPT_LOW_SPEED_TIME, 30);
     curl_easy_setopt(curlhandle, CURLOPT_LOW_SPEED_LIMIT, 200);
 
+    if (!config.sCACertPath.empty())
+        curl_easy_setopt(curlhandle, CURLOPT_CAINFO, config.sCACertPath.c_str());
 }
 
 Website::~Website()
@@ -80,6 +82,11 @@ std::string Website::getResponse(const std::string& url)
             else
                 std::cout << "failed to get error code: " << curl_easy_strerror(result) << " (" << url << ")" << std::endl;
         }
+        else if (result == CURLE_SSL_CACERT)
+        {
+            std::cout << "Try using CA certificate bundle from cURL: https://curl.haxx.se/ca/cacert.pem" << std::endl;
+            std::cout << "Use --cacert to set the path for CA certificate bundle" << std::endl;
+        }
     }
 
     return response;
@@ -150,6 +157,7 @@ std::vector<gameItem> Website::getGames()
         {
             for (unsigned int i = 0; i < root["products"].size(); ++i)
             {
+                std::cerr << "\033[KGetting game names " << "(" << root["page"].asInt() << "/" << root["totalPages"].asInt() << ") " << i+1 << " / " << root["products"].size() << "\r" << std::flush;
                 Json::Value product = root["products"][i];
                 gameItem game;
                 game.name = product["slug"].asString();
@@ -196,14 +204,19 @@ std::vector<gameItem> Website::getGames()
                         }
                     }
 
+                    if (!bDownloadDLCInfo && !config.gamehasdlc.empty())
+                    {
+                        if (config.gamehasdlc.isBlacklisted(game.name))
+                            bDownloadDLCInfo = true;
+                    }
+
                     // Check game specific config
                     if (!config.bUpdateCache) // Disable game specific config files for cache update
                     {
                         gameSpecificConfig conf;
-                        conf.bIgnoreDLCCount = false; // Assume false
+                        conf.bIgnoreDLCCount = bDownloadDLCInfo;
                         Util::getGameSpecificConfig(game.name, &conf);
-                        if (conf.bIgnoreDLCCount)
-                            bDownloadDLCInfo = true;
+                        bDownloadDLCInfo = conf.bIgnoreDLCCount;
                     }
 
                     if (bDownloadDLCInfo && !config.sGameRegex.empty())
@@ -229,6 +242,7 @@ std::vector<gameItem> Website::getGames()
         }
         i++;
     } while (!bAllPagesParsed);
+    std::cerr << std::endl;
 
     delete jsonparser;
 
